## Typing stubs for atheris

This is a [PEP 561](https://peps.python.org/pep-0561/)
type stub package for the [`atheris`](https://github.com/google/atheris) package.
It can be used by type-checking tools like
[mypy](https://github.com/python/mypy/),
[pyright](https://github.com/microsoft/pyright),
[pytype](https://github.com/google/pytype/),
[Pyre](https://pyre-check.org/),
PyCharm, etc. to check code that uses `atheris`. This version of
`types-atheris` aims to provide accurate annotations for
`atheris==2.3.*`.

This stub package is marked as [partial](https://peps.python.org/pep-0561/#partial-stub-packages).
If you find that annotations are missing, feel free to contribute and help complete them.


This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/atheris`](https://github.com/python/typeshed/tree/main/stubs/atheris)
directory.

This package was tested with
mypy 1.15.0,
pyright 1.1.396,
and pytype 2024.10.11.
It was generated from typeshed commit
[`91a90ed1d9644377f4881816bad4b6636c84cb4d`](https://github.com/python/typeshed/commit/91a90ed1d9644377f4881816bad4b6636c84cb4d).